/**
 * Copyright 2019 the orbs-client-sdk-javascript authors
 * This file is part of the orbs-client-sdk-javascript library in the Orbs project.
 *
 * This source code is licensed under the MIT license found in the LICENSE file in the root directory of this source tree.
 * The above notice should be included in all copies or substantial portions of the software.
 */
import { BaseBuilder } from "./Base";
export declare function dateToUnixNano(date: Date, nanoNonce: number): bigint;
export declare function unixNanoToDate(timestamp: bigint): Date;
export declare const ARGUMENT_TYPE_UINT_32_VALUE = 0;
export declare const ARGUMENT_TYPE_UINT_64_VALUE = 1;
export declare const ARGUMENT_TYPE_STRING_VALUE = 2;
export declare const ARGUMENT_TYPE_BYTES_VALUE = 3;
export declare const ARGUMENT_TYPE_BOOL_VALUE = 4;
export declare const ARGUMENT_TYPE_UINT_256_VALUE = 5;
export declare const ARGUMENT_TYPE_BYTES_20_VALUE = 6;
export declare const ARGUMENT_TYPE_BYTES_32_VALUE = 7;
export declare const ARGUMENT_TYPE_UINT_32_ARRAY_VALUE = 8;
export declare const ARGUMENT_TYPE_UINT_64_ARRAY_VALUE = 9;
export declare const ARGUMENT_TYPE_STRING_ARRAY_VALUE = 10;
export declare const ARGUMENT_TYPE_BYTES_ARRAY_VALUE = 11;
export declare const ARGUMENT_TYPE_BOOL_ARRAY_VALUE = 12;
export declare const ARGUMENT_TYPE_UINT_256_ARRAY_VALUE = 13;
export declare const ARGUMENT_TYPE_BYTES_20_ARRAY_VALUE = 14;
export declare const ARGUMENT_TYPE_BYTES_32_ARRAY_VALUE = 15;
export declare const Argument_Scheme: number[];
export declare const Argument_Unions: number[][];
export declare class ArgumentBuilder extends BaseBuilder {
    private fields;
    constructor(fields: {
        type: number;
        value: number | bigint | string | Uint8Array | boolean | Array<number> | Array<bigint> | Array<string> | Array<Uint8Array> | Array<boolean>;
    });
    write(buf: Uint8Array): void;
}
export declare const ArgumentArray_Scheme: number[];
export declare class ArgumentArrayBuilder extends BaseBuilder {
    private fields;
    constructor(fields: {
        arguments: ArgumentBuilder[];
    });
    write(buf: Uint8Array): void;
}
export declare const Event_Scheme: number[];
export declare const EventsArray_Scheme: number[];
export declare class EdDSA01SignerBuilder extends BaseBuilder {
    private fields;
    constructor(fields: {
        networkType: number;
        signerPublicKey: Uint8Array;
    });
    write(buf: Uint8Array): void;
}
export declare class SignerBuilder extends BaseBuilder {
    private fields;
    constructor(fields: {
        scheme: number;
        eddsa: EdDSA01SignerBuilder;
    });
    write(buf: Uint8Array): void;
}
export declare const Signer_Scheme: number[];
export declare const Signer_Unions: number[][];
export declare const EdDSA01Signer_Scheme: number[];
export declare class TransactionBuilder extends BaseBuilder {
    private fields;
    constructor(fields: {
        protocolVersion: number;
        virtualChainId: number;
        timestamp: bigint;
        signer: SignerBuilder;
        contractName: string;
        methodName: string;
        inputArgumentArray: Uint8Array;
    });
    write(buf: Uint8Array): void;
}
export declare const Transaction_Scheme: number[];
export declare const SignedTransaction_Scheme: number[];
export declare class SignedTransactionBuilder extends BaseBuilder {
    private fields;
    constructor(fields: {
        transaction: TransactionBuilder;
        signature: Uint8Array;
    });
    write(buf: Uint8Array): void;
}
export declare const TransactionReceipt_Scheme: number[];
export declare class QueryBuilder extends BaseBuilder {
    private fields;
    constructor(fields: {
        protocolVersion: number;
        virtualChainId: number;
        timestamp: bigint;
        signer: SignerBuilder;
        contractName: string;
        methodName: string;
        inputArgumentArray: Uint8Array;
    });
    write(buf: Uint8Array): void;
}
export declare const SignedQuery_Scheme: number[];
export declare class SignedQueryBuilder extends BaseBuilder {
    private fields;
    constructor(fields: {
        query: QueryBuilder;
        signature: Uint8Array;
    });
    write(buf: Uint8Array): void;
}
export declare const QueryResult_Scheme: number[];
export declare const TransactionsBlockHeader_Scheme: number[];
export declare const ResultsBlockHeader_Scheme: number[];
